"""Compatibility shim for legacy submodule `color_utils.qcolor`.

Re-exports the API from `tintelligence_color_utils.qcolor`.
"""

from __future__ import annotations

from tintelligence_color_utils.qcolor import *  # noqa: F401,F403
